# -*- coding: utf-8 -*-
import logging
import pathlib

from teklia_toolbox.requests import should_verify_cert

import urllib3
from arkindex import ArkindexClient, options_from_env

logging.basicConfig(
    format="[%(asctime)s] [%(levelname)s] %(message)s", level=logging.INFO
)

# Skip SSL verification in Arkindex API client for local development hosts
options = options_from_env()
verify = should_verify_cert(options.get("base_url"))
if not verify:
    urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
    logging.warn("SSL certificate verification is disabled for Arkindex API calls")
default_client = ArkindexClient(verify=verify, **options)

# Read shared VERSION and expose it to Python internals
__version__ = (pathlib.Path(__file__).parent / "VERSION").read_text().strip()

# User-Agent to add in headers for specific requests towards IIIF servers
USER_AGENT = f"arkindex-iiif-import/{__version__}"
