# -*- coding: utf-8 -*-
import json
import logging
from pathlib import Path
from typing import List

from pdfminer.layout import LTChar, LTTextContainer, LTTextLine

logger = logging.getLogger(__name__)


def extract_codes(path):
    """
    Parse an UTF-8 script description and list all the codes as integers
    """
    with open(path) as f:
        return [int(c["code"], 16) for c in json.load(f)["characters"]]


def _process_char(char: LTChar, script: List[int]):
    assert isinstance(char, LTChar)
    text = char.get_text()
    if len(text) == 1:
        # Ignore CID descriptions
        code = ord(text)
        # Check character code against codes list
        if code in script:
            return True


def has_characters_from_script(element: LTTextContainer, script: List[int]):
    """
    Detect if a text container has any characters belonging to a UTF-8 script
    """
    for item in element:
        if isinstance(item, LTChar):
            if _process_char(item, script):
                return True
        elif isinstance(item, LTTextLine):
            for char in item:
                if _process_char(char, script):
                    return True

    # No match found
    return False


def get_text_orientation(element: LTTextContainer):
    """
    Get the text orientation of a given LTTextContainer object.
    Currently only works for Arabic.
    """
    script = extract_codes(Path(__file__).absolute().parent / "assets/Arabic.json")
    if has_characters_from_script(element, script):
        return "horizontal-rl"
    return "horizontal-lr"
