# -*- coding: utf-8 -*-
import requests
from teklia_toolbox.requests import HTTP_GET_RETRY_BACKOFF, should_verify_cert
from tenacity import retry, retry_if_exception_type, stop_after_attempt, wait_fixed


@retry(
    reraise=True,
    retry=retry_if_exception_type(requests.RequestException),
    stop=stop_after_attempt(2),
    wait=wait_fixed(HTTP_GET_RETRY_BACKOFF),
)
def retried_iiif_get(url, headers, timeout, **kwargs):
    """
    Wrapper for requests.get with a retry mechanism.
    The same GET call will be retried 2 times.
    If the 2nd call still gives an exception, that exception is re-raised
    and the caller should catch it
    """
    with requests.get(
        url, headers=headers, timeout=timeout, verify=should_verify_cert(url), **kwargs
    ) as r:
        r.raise_for_status()
        return r
