#!/bin/sh -e
# Build the tasks Docker image.
# Requires CI_PROJECT_DIR and CI_REGISTRY_IMAGE to be set.
# VERSION defaults to latest.
# Will automatically login to a registry if CI_REGISTRY, CI_REGISTRY_USER and CI_REGISTRY_PASSWORD are set.
# Will only push an image if $CI_REGISTRY is set.

if [ -z "$VERSION" ]; then
	#Ensure this is not a base tag
	case $CI_COMMIT_TAG in
		base-*)
			echo build can only be used with non-base tags.
			exit 1;;
	esac
	VERSION=${CI_COMMIT_TAG:-latest}
fi

if [ -z "$VERSION" -o -z "$CI_PROJECT_DIR" -o -z "$CI_REGISTRY_IMAGE" ]; then
	echo Missing environment variables
	exit 1
fi

if [ -n "$DOCKER_AUTH_CONFIG" ]; then
	# Authenticate on docker.io using common credentials to avoid quota issues
	mkdir -p ~/.docker || true
	echo "$DOCKER_AUTH_CONFIG" > ~/.docker/config.json
	docker login index.docker.io
fi

if [ -n "$CI_REGISTRY" -a -n "$CI_REGISTRY_USER" -a -n "$CI_REGISTRY_PASSWORD" ]; then
	echo Logging in to container registry…
	echo $CI_REGISTRY_PASSWORD | docker login -u $CI_REGISTRY_USER --password-stdin $CI_REGISTRY
fi

CLIENT_BRANCH=${CLIENT_BRANCH:-master}
TRANSKRIBUS_BRANCH=${TRANSKRIBUS_BRANCH:-master}
IMAGE_TAG="$CI_REGISTRY_IMAGE:$VERSION"

cd $CI_PROJECT_DIR
docker build . \
	-t "$IMAGE_TAG" \
	--build-arg "CLIENT_BRANCH=$CLIENT_BRANCH" \
	--build-arg "TRANSKRIBUS_BRANCH=$TRANSKRIBUS_BRANCH"
if [ -n "$CI_REGISTRY" ]; then
	docker push "$IMAGE_TAG"
fi

# Also publish on Teklia repository
if [ -n "$CI_COMMIT_TAG" -a -n "$TEKLIA_REGISTRY" ]; then
	echo "$TEKLIA_PASSWORD" | docker login -u "$TEKLIA_USERNAME" --password-stdin "$TEKLIA_REGISTRY"

	IMAGE_TAG_TEKLIA="$TEKLIA_REGISTRY/$CI_PROJECT_PATH:$VERSION"
	docker tag "$IMAGE_TAG" "$IMAGE_TAG_TEKLIA"
	docker push "$IMAGE_TAG_TEKLIA"
fi
