# -*- coding: utf-8 -*-
from unittest import TestCase
from unittest.mock import patch

import requests_mock

from arkindex_tasks.import_files.transkribus import TranskribusFolder


class TestTranskribusFolder(TestCase):
    @requests_mock.Mocker()
    def test_get_folder(self, mock):
        mock.get(
            "/api/v1/corpus/corpusid/elements/?name=Untitled%20(3)&type=book",
            json={
                "count": 2,
                "number": 1,
                "results": [
                    {
                        "id": "wrongfolderid",
                        "name": "Untitled (3) (2)",
                    },
                    {
                        "id": "folderid",
                        "name": "Untitled (3)",
                    },
                ],
            },
        )
        folder = TranskribusFolder(
            # archive and filenames are not needed for this test, but required by the class
            archive=None,
            filenames=[],
            title="Untitled (3)",
            corpus_id="corpusid",
            folder_type={"slug": "book", "display_name": "a book"},
            element_type={"slug": "page", "display_name": "a page"},
            paragraph_type={"slug": "paragraph", "display_name": "a paragraph"},
            line_type={"slug": "line", "display_name": "a line"},
        )
        folder.get_or_create_folder()

        self.assertEqual(mock.call_count, 1)
        self.assertEqual(
            folder.folder,
            {
                "id": "folderid",
                "name": "Untitled (3)",
            },
        )

    @requests_mock.Mocker()
    @patch(
        "arkindex_tasks.import_files.transkribus.WORKER_RUN_ID",
        "aaaaaaaa-aaaa-aaaa-aaaa-aaaaaaaaaaaa",
    )
    def test_create_folder(self, mock):
        mock.get(
            "https://arkindex.teklia.com/api/v1/corpus/corpusid/elements/?name=Untitled%20(3)&type=book",
            json={"count": 0, "number": 1, "results": []},
        )
        mock.post("/api/v1/elements/create/", json={"id": "folderid"})
        folder = TranskribusFolder(
            # archive and filenames are not needed for this test, but required by the class
            archive=None,
            filenames=[],
            title="Untitled (3)",
            corpus_id="corpusid",
            folder_type={"slug": "book", "display_name": "a book"},
            element_type={"slug": "page", "display_name": "a page"},
            paragraph_type={"slug": "paragraph", "display_name": "a paragraph"},
            line_type={"slug": "line", "display_name": "a line"},
        )
        folder.get_or_create_folder()

        self.assertEqual(mock.call_count, 2)
        self.assertEqual(folder.folder, {"id": "folderid"})
        post_request = mock.request_history[1]
        self.assertEqual(post_request.method, "POST")
        self.assertDictEqual(
            post_request.json(),
            {
                "corpus": "corpusid",
                "type": "book",
                "parent": None,
                "name": "Untitled (3)",
                "worker_run_id": "aaaaaaaa-aaaa-aaaa-aaaa-aaaaaaaaaaaa",
            },
        )
